==> aurelia-animator-velocity-1.0.0-rc.1.0.0.jar: META-INF/resources/webjars/aurelia-animator-velocity/1.0.0-rc.1.0.0/doc/CHANGELOG.md <==
<a name="1.0.0-rc.1.0.0"></a>
# [1.0.0-rc.1.0.0](https://github.com/aurelia/animator-velocity/compare/1.0.0-beta.2.0.1...v1.0.0-rc.1.0.0) (2016-06-22)



### 1.0.0-beta.1.2.1 (2016-05-10)


### 1.0.0-beta.1.2.0 (2016-03-22)

* Update to Babel 6

### 1.0.0-beta.1.1.4 (2016-02-08)


### 1.0.0-beta.1.1.3 (2016-01-30)


#### Bug Fixes

* **all:** add d.ts for velocity to build docs ([12357557](https://github.com/aurelia/animator-velocity/commit/12357557e1161a8e90f0488f92d9c378cf4f3bb5))
* **animator:** remove json and replace with simple parser ([a82e59e8](https://github.com/aurelia/animator-velocity/commit/a82e59e87b2ba2c9bcf806a5079562a6b12889e3))


### 1.0.0-beta.1.1.0 (2016-01-29)


#### Bug Fixes

* **animator:** mark animate params as optional ([b6888ba6](https://github.com/aurelia/animator-velocity/commit/b6888ba645810911ac490d7b8ee121574500700d))


#### Features

* **all:** update jspm meta; core-js; aurelia deps ([aa84d30d](https://github.com/aurelia/animator-velocity/commit/aa84d30d3cc1b63eee633d105289af768eb4deaf))


### 1.0.0-beta.1.0.1 (2016-01-08)


#### Bug Fixes

* **animator:** add missing addClass and removeClass interface memebers ([67a8793f](https://github.com/aurelia/animator-velocity/commit/67a8793fcac53ab7d079d619050377f529bc29c5))


### 0.3.3 (2015-11-16)


### 0.3.1 (2015-11-16)


## 0.3.0 (2015-11-10)


#### Bug Fixes

* **all:** update to use TemplatingEngine to configure the animator ([1d51f9f0](https://github.com/aurelia/animator-velocity/commit/1d51f9f08a1c155d71fad44a6efe9346f73c466e))
* **dependencies:** github version of velocity does not install correctly ([8490a63d](https://github.com/aurelia/animator-velocity/commit/8490a63d4b4a8efa940969f576932b001fd26476))


## 0.2.0 (2015-10-13)


#### Features

* **all:** incorporate pal ([d4e577d0](https://github.com/aurelia/animator-velocity/commit/d4e577d0ff4ca73f3809062d2e86a518c5822a75))


## 0.1.0 (2015-10-04)

==> aurelia-animator-velocity-1.0.1.jar: META-INF/resources/webjars/aurelia-animator-velocity/1.0.1/doc/CHANGELOG.md <==
<a name="1.0.1"></a>
## [1.0.1](https://github.com/aurelia/animator-velocity/compare/1.0.0...v1.0.1) (2016-09-22)

#### Bug Fixes

* Make enter and leave animations optional
* Enable anim-enter and anim-leave values to work correctly

<a name="1.0.0"></a>
# [1.0.0](https://github.com/aurelia/animator-velocity/compare/1.0.0-rc.1.0.0...v1.0.0) (2016-07-27)



<a name="1.0.0-rc.1.0.0"></a>
# [1.0.0-rc.1.0.0](https://github.com/aurelia/animator-velocity/compare/1.0.0-beta.2.0.1...v1.0.0-rc.1.0.0) (2016-06-22)



### 1.0.0-beta.1.2.1 (2016-05-10)


### 1.0.0-beta.1.2.0 (2016-03-22)

* Update to Babel 6

### 1.0.0-beta.1.1.4 (2016-02-08)


### 1.0.0-beta.1.1.3 (2016-01-30)


#### Bug Fixes

* **all:** add d.ts for velocity to build docs ([12357557](https://github.com/aurelia/animator-velocity/commit/12357557e1161a8e90f0488f92d9c378cf4f3bb5))
* **animator:** remove json and replace with simple parser ([a82e59e8](https://github.com/aurelia/animator-velocity/commit/a82e59e87b2ba2c9bcf806a5079562a6b12889e3))


### 1.0.0-beta.1.1.0 (2016-01-29)


#### Bug Fixes

* **animator:** mark animate params as optional ([b6888ba6](https://github.com/aurelia/animator-velocity/commit/b6888ba645810911ac490d7b8ee121574500700d))


#### Features

* **all:** update jspm meta; core-js; aurelia deps ([aa84d30d](https://github.com/aurelia/animator-velocity/commit/aa84d30d3cc1b63eee633d105289af768eb4deaf))


### 1.0.0-beta.1.0.1 (2016-01-08)


#### Bug Fixes

* **animator:** add missing addClass and removeClass interface memebers ([67a8793f](https://github.com/aurelia/animator-velocity/commit/67a8793fcac53ab7d079d619050377f529bc29c5))


### 0.3.3 (2015-11-16)


### 0.3.1 (2015-11-16)


## 0.3.0 (2015-11-10)


#### Bug Fixes

* **all:** update to use TemplatingEngine to configure the animator ([1d51f9f0](https://github.com/aurelia/animator-velocity/commit/1d51f9f08a1c155d71fad44a6efe9346f73c466e))
* **dependencies:** github version of velocity does not install correctly ([8490a63d](https://github.com/aurelia/animator-velocity/commit/8490a63d4b4a8efa940969f576932b001fd26476))


## 0.2.0 (2015-10-13)


#### Features

* **all:** incorporate pal ([d4e577d0](https://github.com/aurelia/animator-velocity/commit/d4e577d0ff4ca73f3809062d2e86a518c5822a75))


## 0.1.0 (2015-10-04)
